@@ -54,6 +54,14 @@ class LogHandle(object):
 
         self.__base_name = base_name
 
+    @property
+    def gc(self):
+        return self.__gui_console
+
+    @gc.setter
+    def gc(self, gc):
+        self.__gui_console = gc
+
     @staticmethod
     def __clean_handlers():
         for handler in logging.root.handlers[:]:
@@ -120,11 +128,16 @@ class GUIConsole(Toplevel):
         Class to show logging in a GUI window by using Toplevel in tkinter
     """
 
-    def __init__(self):
+    def __init__(self, parent):
         Toplevel.__init__(self)
+        self.__parent = parent
+        self.bind('<Destroy>', self.__cleanup)
         self.__build()
         self.__start_idle()
 
+    def __cleanup(self):
+        self.__parent.gc = None
+
     def __start_idle(self):
         self.after(5, self.__on_idle)
 
